@@ -136,17 +136,20 @@ class Corpus(Table):
             metadata (numpy.ndarray): Meta data
             Y (numpy.ndarray): Class variables
         """
+        if np.prod(self.X.shape) != 0:
+            raise ValueError("Extending corpus only works when X is empty"
+                             "while the shape of X is {}".format(self.X.shape))
 
         self.metas = np.vstack((self.metas, metadata))
 
         cv = self.domain.class_var
-        for val in set(Y):
+        for val in set(filter(None, Y)):
             if val not in cv.values:
                 cv.add_value(val)
         new_Y = np.array([cv.to_val(i) for i in Y])[:, None]
         self._Y = np.vstack((self._Y, new_Y))
 
-        self.X = self.W = np.zeros((len(self), 0))
+        self.X = self.W = np.zeros((self.metas.shape[0], 0))
         Table._init_ids(self)
 
         self._tokens = None     # invalidate tokens
@@ -437,9 +440,6 @@ class Corpus(Table):
             new.attributes = orig.attributes
             new.used_preprocessor = orig.used_preprocessor
 
-    def __len__(self):
-        return len(self.metas)
-
     def __eq__(self, other):
         def arrays_equal(a, b):
             if sp.issparse(a) != sp.issparse(b):
