@@ -3,7 +3,7 @@
 To use preprocessing you should create a corpus::
 
     >>> from orangecontrib.text import Corpus
-    >>> corpus = Corpus.from_file('bookexcerpts')
+    >>> corpus = Corpus.from_file('book-excerpts')
 
 And create a :class:`Preprocessor` objects with methods you want:
 
@@ -31,11 +31,8 @@ if no preprocessing was applied yet::
 
 """
 import nltk
-from orangecontrib.text.misc import nltk_data_dir
 
-# Ensure NLTK data is present
-NLTK_DATA = ["wordnet", "stopwords", "punkt"]
-nltk.download(NLTK_DATA, download_dir=nltk_data_dir(), quiet=True)
+nltk.download(["wordnet", "stopwords", "punkt"])
 
 from .filter import *
 from .normalize import *
