@@ -8,7 +8,7 @@ from AnyQt.QtWidgets import (QWidget, QLabel, QHBoxLayout, QVBoxLayout,
                              QScrollArea)
 
 from Orange.widgets import gui, settings, widget
-from Orange.widgets.widget import OWWidget, Msg
+from Orange.widgets.widget import OWWidget, Msg, Input, Output
 from orangecontrib.text import preprocess
 from orangecontrib.text.corpus import Corpus
 from orangecontrib.text.misc import nltk_data_dir
@@ -23,14 +23,6 @@ def _i(name, icon_path='icons'):
     return os.path.join(widget_path, icon_path, name)
 
 
-class Input:
-    CORPUS = 'Corpus'
-
-
-class Output:
-    PP_CORPUS = 'Corpus'
-
-
 class OnOffButton(QPushButton):
     stateChanged = pyqtSignal()
 
@@ -329,8 +321,8 @@ class FilteringModule(MultipleMethodModule):
 
     pattern = settings.Setting('\.|,|:|;|!|\?|\(|\)|\||\+|\'|\"|‘|’|“|”|\'|\’'
                                '|…|\-|–|—|\$|&|\*|>|<')
-    min_df = settings.Setting(0.)
-    max_df = settings.Setting(1.)
+    min_df = settings.Setting(0.1)
+    max_df = settings.Setting(0.9)
     keep_n = settings.Setting(100)
     use_keep_n = settings.Setting(False)
     use_df = settings.Setting(False)
@@ -396,11 +388,13 @@ class FilteringModule(MultipleMethodModule):
         if self.FREQUENCY in self.checked:
             self.frequency_filter.min_df = self.min_df
             self.frequency_filter.max_df = self.max_df
+        else:
+            checked.append(self.FREQUENCY)
+            self.frequency_filter.min_df = 0
+            self.frequency_filter.max_df = 1.0
 
         if self.KEEP_N in checked:
             checked.pop(checked.index(self.KEEP_N))
-            if self.FREQUENCY not in self.checked:
-                checked.append(self.FREQUENCY)
             self.frequency_filter.keep_n = self.keep_n
         else:
             self.frequency_filter.keep_n = None
@@ -508,8 +502,11 @@ class OWPreprocess(OWWidget):
     icon = 'icons/TextPreprocess.svg'
     priority = 30
 
-    inputs = [(Input.CORPUS, Corpus, 'set_data')]
-    outputs = [(Output.PP_CORPUS, Corpus)]
+    class Inputs:
+        corpus = Input("Corpus", Corpus)
+
+    class Outputs:
+        corpus = Output("Corpus", Corpus)
 
     autocommit = settings.Setting(True)
 
@@ -596,6 +593,7 @@ class OWPreprocess(OWWidget):
 
         self.buttonsArea.layout().addWidget(commit_button)
 
+    @Inputs.corpus
     def set_data(self, data=None):
         self.corpus = data.copy() if data is not None else None
         self.initial_ngram_range = data.ngram_range if data is not None else None
@@ -617,7 +615,7 @@ class OWPreprocess(OWWidget):
             self.apply()
         else:
             self.update_info()
-            self.send(Output.PP_CORPUS, None)
+            self.Outputs.corpus.send(None)
 
     def apply(self):
         self.preprocess()
@@ -644,7 +642,7 @@ class OWPreprocess(OWWidget):
         if result is not None and len(result.dictionary) == 0:
             self.Warning.no_token_left()
             result = None
-        self.send(Output.PP_CORPUS, result)
+        self.Outputs.corpus.send(result)
         self.progressBarFinished(None)
 
     def set_minimal_width(self):
@@ -667,7 +665,7 @@ if __name__ == '__main__':
     app = QApplication([])
     widget = OWPreprocess()
     widget.show()
-    corpus = Corpus.from_file('bookexcerpts')
+    corpus = Corpus.from_file('book-excerpts')
     widget.set_data(corpus)
     app.exec()
     widget.saveSettings()
