@@ -1,12 +1,14 @@
 import functools
 
+from AnyQt import QtGui, QtCore
 from AnyQt.QtCore import pyqtSignal, QSize
 from AnyQt.QtWidgets import (QVBoxLayout, QButtonGroup, QRadioButton,
-                             QGroupBox, QTreeWidgetItem, QTreeWidget)
+                             QGroupBox, QTreeWidgetItem, QTreeWidget,
+                             QStyleOptionViewItem, QStyledItemDelegate, QStyle)
 
 from Orange.widgets import settings
 from Orange.widgets import gui
-from Orange.widgets.widget import OWWidget
+from Orange.widgets.widget import OWWidget, Input, Output
 from Orange.data import Table
 from Orange.widgets.data.contexthandlers import DomainContextHandler
 from orangecontrib.text.corpus import Corpus
@@ -84,11 +86,6 @@ class HdpWidget(TopicWidget):
     tau = settings.Setting(64)
 
 
-class Output:
-    CORPUS = "Corpus"
-    TOPIC = "Topic"
-
-
 def require(attribute):
     def decorator(func):
         @functools.wraps(func)
@@ -108,9 +105,14 @@ class OWTopicModeling(OWWidget):
     settingsHandler = DomainContextHandler()
 
     # Input/output
-    inputs = [("Corpus", Corpus, "set_data")]
-    outputs = [(Output.CORPUS, Table),
-               (Output.TOPIC, Topic)]
+    class Inputs:
+        corpus = Input("Corpus", Corpus)
+
+    class Outputs:
+        corpus = Output("Corpus", Table)
+        selected_topic = Output("Selected Topic", Topic)
+        all_topics = Output("All Topics", Table)
+
     want_main_area = True
 
     methods = [
@@ -165,6 +167,7 @@ class OWTopicModeling(OWWidget):
         self.mainArea.layout().addWidget(self.topic_desc)
         self.topic_desc.setFocus()
 
+    @Inputs.corpus
     def set_data(self, data=None):
         self.corpus = data
         self.apply()
@@ -206,10 +209,12 @@ class OWTopicModeling(OWWidget):
     @learning_task.on_result
     def on_result(self, corpus):
         self.progressBarFinished(None)
-        self.send(Output.CORPUS, corpus)
+        self.Outputs.corpus.send(corpus)
+        self.Outputs.all_topics.send(self.model.get_all_topics_table())
         if corpus is None:
             self.topic_desc.clear()
-            self.send(Output.TOPIC, None)
+            self.Outputs.selected_topic.send(None)
+            self.Outputs.all_topics.send(None)
         else:
             self.topic_desc.show_model(self.model)
 
@@ -220,22 +225,37 @@ class OWTopicModeling(OWWidget):
     def send_report(self):
         self.report_items(*self.widgets[self.method_index].report_model())
         if self.corpus is not None:
-            self.report_items('Topics', [(i+1, ', '.join(self.model.get_top_words_by_id(i)))
-                                         for i in range(len(self.model.topic_names))])
+            self.report_items('Topics', self.topic_desc.report())
 
     def send_topic_by_id(self, topic_id=None):
         if self.model.model and topic_id is not None:
-            self.send(Output.TOPIC, self.model.get_topics_table_by_id(topic_id))
+            self.Outputs.selected_topic.send(self.model.get_topics_table_by_id(topic_id))
 
 
 class TopicViewerTreeWidgetItem(QTreeWidgetItem):
-    def __init__(self, topic_id, words, parent):
+    def __init__(self, topic_id, words, weights, parent,
+                 color_by_weights=False):
         super().__init__(parent)
         self.topic_id = topic_id
         self.words = words
+        self.weights = weights
+        self.color_by_weights = color_by_weights
 
         self.setText(0, '{:d}'.format(topic_id + 1))
-        self.setText(1, ', '.join(words))
+        self.setText(1, ', '.join(self._color(word, weight)
+                                  for word, weight in zip(words, weights)))
+
+    def _color(self, word, weight):
+        if self.color_by_weights:
+            red = '#ff6600'
+            green = '#00cc00'
+            color = green if weight > 0 else red
+            return '<span style="color: {}">{}</span>'.format(color, word)
+        else:
+            return word
+
+    def report(self):
+        return self.text(0), self.text(1)
 
 
 class TopicViewer(QTreeWidget):
@@ -252,6 +272,7 @@ class TopicViewer(QTreeWidget):
         self.setHeaderLabels(self.columns)
         self.resize_columns()
         self.itemSelectionChanged.connect(self.selected_topic_changed)
+        self.setItemDelegate(HTMLDelegate())    # enable colors
 
     def resize_columns(self):
         for i in range(self.columnCount()):
@@ -261,9 +282,11 @@ class TopicViewer(QTreeWidget):
         self.clear()
         if topic_model.model:
             for i in range(topic_model.num_topics):
-                words = topic_model.get_top_words_by_id(i)
+                words, weights = topic_model.get_top_words_by_id(i)
                 if words:
-                    it = TopicViewerTreeWidgetItem(i, words, self)
+                    it = TopicViewerTreeWidgetItem(
+                        i, words, weights, self,
+                        color_by_weights=topic_model.has_negative_weights)
                     self.addTopLevelItem(it)
 
             self.resize_columns()
@@ -278,16 +301,62 @@ class TopicViewer(QTreeWidget):
         else:
             self.topicSelected.emit(None)
 
+    def report(self):
+        root = self.invisibleRootItem()
+        child_count = root.childCount()
+        return [root.child(i).report()
+                for i in range(child_count)]
+
     def sizeHint(self):
         return QSize(700, 300)
 
 
+class HTMLDelegate(QStyledItemDelegate):
+    """ This delegate enables coloring of words in QTreeWidgetItem. 
+    Adopted from https://stackoverflow.com/a/5443112/892987 """
+    def paint(self, painter, option, index):
+        options = QStyleOptionViewItem(option)
+        self.initStyleOption(options,index)
+
+        style = QApplication.style() if options.widget is None else options.widget.style()
+
+        doc = QtGui.QTextDocument()
+        doc.setHtml(options.text)
+
+        options.text = ""
+        style.drawControl(QStyle.CE_ItemViewItem, options, painter)
+
+        ctx = QtGui.QAbstractTextDocumentLayout.PaintContext()
+
+        if options.state & QStyle.State_Selected:
+            ctx.palette.setColor(QtGui.QPalette.Text,
+                                 options.palette.color(QtGui.QPalette.Active,
+                                                       QtGui.QPalette.HighlightedText))
+
+        textRect = style.subElementRect(QStyle.SE_ItemViewItemText, options)
+        painter.save()
+        painter.translate(textRect.topLeft())
+        painter.setClipRect(textRect.translated(-textRect.topLeft()))
+        doc.documentLayout().draw(painter, ctx)
+
+        painter.restore()
+
+    def sizeHint(self, option, index):
+        options = QStyleOptionViewItem(option)
+        self.initStyleOption(options,index)
+
+        doc = QtGui.QTextDocument()
+        doc.setHtml(options.text)
+        doc.setTextWidth(options.rect.width())
+        return QtCore.QSize(doc.idealWidth(), doc.size().height())
+
+
 if __name__ == '__main__':
     from AnyQt.QtWidgets import QApplication
 
     app = QApplication([])
     widget = OWTopicModeling()
-    # widget.set_data(Corpus.from_file('bookexcerpts'))
+    # widget.set_data(Corpus.from_file('book-excerpts'))
     widget.set_data(Corpus.from_file('deerwester'))
     widget.show()
     app.exec()
