@@ -8,32 +8,28 @@ from AnyQt.QtCore import Qt, QItemSelection, QItemSelectionModel, pyqtSlot, \
     QObject, QSortFilterProxyModel
 from AnyQt.QtWidgets import QApplication
 
-from Orange.data import StringVariable, ContinuousVariable, Domain
+from Orange.data import StringVariable, ContinuousVariable, Domain, Table
 from Orange.data.util import scale
 from Orange.widgets import widget, gui, settings
 from Orange.widgets.utils.itemmodels import PyTableModel
+from Orange.widgets.widget import Input, Output
 from orangecontrib.text.corpus import Corpus
 from orangecontrib.text.topics import Topic
 
 
-class IO:
-    CORPUS = 'Corpus'
-    TOPIC = 'Topic'
-    SELECTED_WORDS = 'Selected Words'
-
-
 class OWWordCloud(widget.OWWidget):
     name = "Word Cloud"
     priority = 10000
     icon = "icons/WordCloud.svg"
-    inputs = [
-        (IO.CORPUS, Corpus, 'on_corpus_change', widget.Default),
-        (IO.TOPIC, Topic, 'on_topic_change'),
-    ]
-    outputs = [
-        (IO.CORPUS, Corpus),
-        (IO.SELECTED_WORDS, Topic),
-    ]
+
+    class Inputs:
+        corpus = Input("Corpus", Corpus, default=True)
+        topic = Input("Topic", Topic)
+
+    class Outputs:
+        corpus = Output("Corpus", Corpus)
+        selected_words = Output("Selected Words", Topic, dynamic=False)
+        word_counts = Output("Word Counts", Table)
 
     graph_name = 'webview'
 
@@ -191,6 +187,7 @@ span.selected {color:red !important}
         self.wordlist = np.c_[words, weights].tolist()
         self.on_cloud_pref_change()
 
+    @Inputs.topic
     def on_topic_change(self, data):
         self.topic = data
         self.topic_info.setVisible(data is not None)
@@ -215,10 +212,27 @@ span.selected {color:red !important}
         self._repopulate_wordcloud(words, weights)
 
     def _apply_corpus(self):
-        counts = self.corpus_counter.most_common()
-        words, freq = zip(*counts) if counts else ([], [])
+        words, freq = self.word_frequencies()
         self._repopulate_wordcloud(words, freq)
 
+    def word_frequencies(self):
+        counts = self.corpus_counter.most_common()
+        words, freq = zip(*counts) if counts else ([], [])
+        return words, freq
+
+    def create_weight_list(self):
+        wc_table = None
+        if self.corpus is not None:
+            words, freq = self.word_frequencies()
+            words = np.array(words)[:, None]
+            w_count = np.array(freq)[:, None]
+            domain = Domain([ContinuousVariable('Word Count')],
+                            metas=[StringVariable('Word')])
+            wc_table = Table.from_numpy(domain, X=w_count, metas=words)
+            wc_table.name = 'Word Counts'
+        self.Outputs.word_counts.send(wc_table)
+
+    @Inputs.corpus
     def on_corpus_change(self, data):
         self.corpus = data
 
@@ -230,6 +244,8 @@ span.selected {color:red !important}
         self.documents_info_str = ('{} documents with {} words'.format(n_docs, n_words)
                                    if data else '(no documents on input)')
 
+        self.create_weight_list()
+
     def handleNewSignals(self):
         if self.topic is not None and len(self.topic):
             self._apply_topic()
@@ -269,7 +285,7 @@ span.selected {color:red !important}
             rows = [i for i, doc in enumerate(self.corpus.ngrams)
                     if any(word in doc for word in self.selected_words)]
             out = self.corpus[rows]
-        self.send(IO.CORPUS, out)
+        self.Outputs.corpus.send(out)
 
         topic = None
         words = list(self.selected_words)
@@ -278,7 +294,7 @@ span.selected {color:red !important}
                                      X=np.empty((len(words), 0)),
                                      metas=np.c_[words].astype(object))
             topic.name = 'Selected Words'
-        self.send(IO.SELECTED_WORDS, topic)
+        self.Outputs.selected_words.send(topic)
 
 
 def main():
